@@ -4,7 +4,7 @@
 #
 # @author: Eric Lapouyade
 
-__version__ = '0.1.8'
+__version__ = '0.1.9'
 __author__ = 'Eric Lapouyade'
 __copyright__ = 'Copyright 2015, python-textops project'
 __credits__ = ['Eric Lapouyade']
@@ -25,7 +25,7 @@ logger = logging.getLogger(__name__)
 logger.addHandler(NullHandler())
 
 from base import TextOp, WrapOp, WrapOpIter, WrapOpStr, add_textop, add_textop_iter, \
-                 StrExt, UnicodeExt, ListExt, DictExt, NoAttrDict, NoAttr, \
-                 DefaultDict, string_formatter, vformat, dformat, activate_debug, pp
+                 StrExt, UnicodeExt, ListExt, DictExt, NoAttrDict, NoAttr, DefaultList, \
+                 DefaultDict, string_formatter, vformat, dformat, eformat, activate_debug, pp
 import ops
 from ops import *
